@@ -135,7 +135,7 @@ Configuration = {
     # "_profile_prepare_sql": False,
     # "profile_dbc_close": False,
     #
-    # "trace_http_client_ip_header_key": "",
+    "trace_http_client_ip_header_key": "",
     # "trace_user_enabled": True,
     # "trace_user_using_ip": False,
     # "trace_user_using_type": 1,
