@@ -8,24 +8,27 @@ class Configure(object):
     dev = False
     net_udp_port = 6600
     last_loaded = 0
+    last_config_modified = 0
 
     @classmethod
     def init(cls, display=True):
-        for key, value in Configuration.items():
-            setattr(cls, key, value)
-        
-        m= cls.load(display)
-        cls.last_loaded = int(time.time())
 
-        return m
-    
+        cls.last_loaded = time.time()
+        return cls.load(display)
+
     @classmethod
     def load(cls, display=True):
         home = 'WHATAP_HOME'
         try:
-            with open(os.path.join(os.environ[home],
-                                   os.environ['WHATAP_CONFIG']), 'r') as f:
+            whatap_config = os.path.join(os.environ[home],os.environ['WHATAP_CONFIG'])
+            last_modified = os.path.getmtime(whatap_config)
+            if cls.last_config_modified >= last_modified:
+                return True
+            for key, value in Configuration.items():
+                setattr(cls, key, value)
+            with open(whatap_config, 'r') as f:
                 for line in f:
+                    cls.last_config_modified = last_modified
                     line_strip = line.strip()
                     if not line_strip or line_strip.startswith('#'):
                         continue
