@@ -13,12 +13,10 @@ def instrument(module):
     def wrapper(fn):
         @trace_handler(fn, True)
         def trace(*args, **kwargs):
-            try:
-                now = int(time.time())
-                if now - conf.last_loaded > init_load_interval:
-                    conf.init(False)
-            except Exception as e:
-                print(e)
+            now = time.time()
+            if now - conf.last_loaded > init_load_interval:
+                conf.init(False)
+
             callback = interceptor(fn, *args, **kwargs)
             
             return callback
@@ -91,14 +89,13 @@ def instrument_handlers_base(module):
     def get_response_wrapper(fn):
         @trace_handler(fn)
         def trace(*args, **kwargs):
-
-            request = args[1]
             callback = fn(*args, **kwargs)
-
+            request = args[1]
             ctx = TraceContextManager.getLocalContext()
             if ctx and conf.trace_user_enabled:
                 if not conf.trace_user_using_ip:
                     userid_util.setUserId(request, callback, ctx._rawuserid )
+
             return callback
 
         return trace
