@@ -95,10 +95,10 @@ def interceptor(rn_environ, *args, **kwargs):
     ctx.remoteIp = environ.get('REMOTE_ADDR', '')
     ctx.userAgentString = environ.get('HTTP_USER_AGENT', '')
     ctx.referer = environ.get('HTTP_REFERER''', '')
-    
+
     if conf.trace_user_enabled:
         if conf.trace_user_using_ip:
-            ctx.userid = ctx.remoteIp
+            ctx.userid = userid_util.getRemoteAddr(args)
         else:
             ctx.userid, ctx._rawuserid = userid_util.getUserId(args, ctx.remoteIp)
 
